pub struct SqliteJobStore { /* private fields */ }Expand description
SQLite-backed job store implementing every job port.
Implementations
Sourceimpl SqliteJobStore
impl SqliteJobStore
pub const fn new(pool: SqlitePool) -> Self
Sourcepub async fn enqueue_in(
&self,
transaction: &mut Transaction<'_, Sqlite>,
record: JobRecord,
) -> Result<EnqueueOutcome, JobError>
pub async fn enqueue_in( &self, transaction: &mut Transaction<'_, Sqlite>, record: JobRecord, ) -> Result<EnqueueOutcome, JobError>
Insert the job and its first publication generation inside the caller’s transaction so the business mutation and the durable dispatch commit atomically.
Sourcepub async fn ingest_in(
&self,
transaction: &mut Transaction<'_, Sqlite>,
record: JobRecord,
) -> Result<IngestOutcome, JobError>
pub async fn ingest_in( &self, transaction: &mut Transaction<'_, Sqlite>, record: JobRecord, ) -> Result<IngestOutcome, JobError>
Insert the job with its publication recorded as already delivered (Scheduler ingestion) inside the caller’s transaction.